@@ -4,22 +4,13 @@
 API:
 * *preprocess* (function): Easy-to-use preprocessing tool.
 
-Example:
-    Preprocess an string:
-
-        >>> from reason import preprocess
-
-        >>> text = "What's up? I love using Reason library!"
-        >>> preprocess(text)
-        [["what's", 'up', '?'], ['i', 'love', 'us', 'reason', 'librari', '!']]
-
 """
 from .tokenize import sent_tokenize, word_tokenize
 from .stem import PorterStemmer
 
 
 def preprocess(corpus):
-    """Stem finding method.
+    """Preprocess function.
 
     Tokenize input corpus to sentences and words, then finds token stems
     using porter stemmer.
@@ -31,7 +22,13 @@ def preprocess(corpus):
         list: Preprocessed text.
 
     Raises:
-        Exception: If input is not string or a list of strings.
+        TypeError: If input is not string or a list of strings.
+
+    Example:
+        >>> from reason import preprocess
+        >>> text = "What's up? I love using Reason library!"
+        >>> preprocess(text)
+        [["what's", 'up', '?'], ['i', 'love', 'us', 'reason', 'librari', '!']]
 
     """
     try:
